/**
 * Copyright (c) 2011, Ben Fortuna
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  o Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 *  o Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 *  o Neither the name of Ben Fortuna nor the names of any other contributors
 * may be used to endorse or promote products derived from this software
 * without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.mnode.ousia.tracker;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import org.pushingpixels.flamingo.api.ribbon.JRibbonFrame;

public class JRibbonFrameTracker extends FrameTracker implements PropertyChangeListener {

	private final JRibbonFrame ribbonFrame;
	
	public JRibbonFrameTracker(JRibbonFrame component) {
		super(component);
		this.ribbonFrame = component;
		ribbonFrame.getRibbon().setMinimized(isMinimized());
		ribbonFrame.getRibbon().addPropertyChangeListener(this);
	}

	public JRibbonFrameTracker(JRibbonFrame component, String id) {
		super(component, id);
		this.ribbonFrame = component;
		ribbonFrame.getRibbon().setMinimized(isMinimized());
		ribbonFrame.getRibbon().addPropertyChangeListener(this);
	}

	@Override
    public void propertyChange(PropertyChangeEvent e) {
        if ("minimized".equals(e.getPropertyName())) {
    		getPreferences().putBoolean(getUniqueId() + ".minimized", ribbonFrame.getRibbon().isMinimized());
        }
	}
	
	public boolean isMinimized() {
		return getPreferences().getBoolean(getUniqueId() + ".minimized", ribbonFrame.getRibbon().isMinimized());
	}
}
